Welcome to src’s documentation! — src documentation

# Welcome to src’s documentation!

Contents:

- PyFemtet package
  - Subpackages
    - PyFemtet.opt package
      - Submodules
      - PyFemtet.opt.core module
      - PyFemtet.opt.visualization module
      - Module contents
    - PyFemtet.tools package
      - Submodules
      - PyFemtet.tools.FemtetClassConst module
      - Module contents
  - Module contents

# Indices and tables

- Index

- Module Index

- Search Page